@@ -50,7 +50,6 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen_port').with('value' => '8774')
         is_expected.to contain_nova_config('DEFAULT/metadata_listen').with('value' => '0.0.0.0')
         is_expected.to contain_nova_config('DEFAULT/metadata_listen_port').with('value' => '8775')
-        is_expected.to contain_nova_config('DEFAULT/osapi_volume_listen').with('value' => '0.0.0.0')
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_workers').with('value' => '5')
         is_expected.to contain_nova_config('DEFAULT/metadata_workers').with('value' => '5')
         is_expected.to contain_nova_config('api/fping_path').with('value' => '/usr/sbin/fping')
@@ -151,7 +150,6 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen_port').with('value' => '8874')
         is_expected.to contain_nova_config('DEFAULT/metadata_listen').with('value' => '127.0.0.1')
         is_expected.to contain_nova_config('DEFAULT/metadata_listen_port').with('value' => '8875')
-        is_expected.to contain_nova_config('DEFAULT/osapi_volume_listen').with('value' => '192.168.56.210')
         is_expected.to contain_nova_config('api/use_forwarded_for').with('value' => false)
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_workers').with('value' => '1')
         is_expected.to contain_nova_config('DEFAULT/metadata_workers').with('value' => '2')
@@ -340,10 +338,6 @@ describe 'nova::api' do
          }"
       end
 
-      it 'disable metadata in evenlet configuration' do
-        is_expected.to contain_nova_config('DEFAULT/enabled_apis').with('value' => '')
-      end
-
       it 'disable nova API service' do
           is_expected.to contain_service('nova-api').with(
           :ensure => 'stopped',
