@@ -13,14 +13,14 @@ describe 'nova::metadata::novajoin::authtoken' do
       it 'configure keystone_authtoken' do
         is_expected.to contain_novajoin_config('keystone_authtoken/username').with_value('novajoin')
         is_expected.to contain_novajoin_config('keystone_authtoken/password').with_value('novajoin_password')
-        is_expected.to contain_novajoin_config('keystone_authtoken/auth_url').with_value('http://127.0.0.1:35357/')
+        is_expected.to contain_novajoin_config('keystone_authtoken/auth_url').with_value('http://127.0.0.1:5000/')
         is_expected.to contain_novajoin_config('keystone_authtoken/project_name').with_value('services')
         is_expected.to contain_novajoin_config('keystone_authtoken/user_domain_name').with_value('Default')
         is_expected.to contain_novajoin_config('keystone_authtoken/project_domain_name').with_value('Default')
         is_expected.to contain_novajoin_config('keystone_authtoken/insecure').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_novajoin_config('keystone_authtoken/auth_section').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_novajoin_config('keystone_authtoken/auth_type').with_value('password')
-        is_expected.to contain_novajoin_config('keystone_authtoken/auth_uri').with_value('http://127.0.0.1:5000/')
+        is_expected.to contain_novajoin_config('keystone_authtoken/www_authenticate_uri').with_value('http://127.0.0.1:5000/')
         is_expected.to contain_novajoin_config('keystone_authtoken/auth_version').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_novajoin_config('keystone_authtoken/cache').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_novajoin_config('keystone_authtoken/cafile').with_value('<SERVICE DEFAULT>')
@@ -38,7 +38,7 @@ describe 'nova::metadata::novajoin::authtoken' do
         is_expected.to contain_novajoin_config('keystone_authtoken/memcache_pool_maxsize').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_novajoin_config('keystone_authtoken/memcache_pool_socket_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_novajoin_config('keystone_authtoken/memcache_pool_unused_timeout').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_novajoin_config('keystone_authtoken/memcache_secret_key').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_novajoin_config('keystone_authtoken/memcache_secret_key').with_value('<SERVICE DEFAULT>').with_secret(true)
         is_expected.to contain_novajoin_config('keystone_authtoken/memcache_security_strategy').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_novajoin_config('keystone_authtoken/memcache_use_advanced_pool').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_novajoin_config('keystone_authtoken/memcached_servers').with_value('<SERVICE DEFAULT>')
@@ -50,10 +50,10 @@ describe 'nova::metadata::novajoin::authtoken' do
     context 'when overriding parameters' do
       before do
         params.merge!({
-          :auth_uri                             => 'https://10.0.0.1:9999/',
+          :www_authenticate_uri                 => 'https://10.0.0.1:9999/',
           :username                             => 'myuser',
           :password                             => 'mypasswd',
-          :auth_url                             => 'http://:127.0.0.1:35357',
+          :auth_url                             => 'http://:127.0.0.1:5000',
           :project_name                         => 'service_project',
           :user_domain_name                     => 'domainX',
           :project_domain_name                  => 'domainX',
@@ -90,7 +90,7 @@ describe 'nova::metadata::novajoin::authtoken' do
       end
 
       it 'configure keystone_authtoken' do
-        is_expected.to contain_novajoin_config('keystone_authtoken/auth_uri').with_value('https://10.0.0.1:9999/')
+        is_expected.to contain_novajoin_config('keystone_authtoken/www_authenticate_uri').with_value('https://10.0.0.1:9999/')
         is_expected.to contain_novajoin_config('keystone_authtoken/username').with_value(params[:username])
         is_expected.to contain_novajoin_config('keystone_authtoken/password').with_value(params[:password]).with_secret(true)
         is_expected.to contain_novajoin_config('keystone_authtoken/auth_url').with_value(params[:auth_url])
@@ -117,7 +117,7 @@ describe 'nova::metadata::novajoin::authtoken' do
         is_expected.to contain_novajoin_config('keystone_authtoken/memcache_pool_maxsize').with_value(params[:memcache_pool_maxsize])
         is_expected.to contain_novajoin_config('keystone_authtoken/memcache_pool_socket_timeout').with_value(params[:memcache_pool_socket_timeout])
         is_expected.to contain_novajoin_config('keystone_authtoken/memcache_pool_unused_timeout').with_value(params[:memcache_pool_unused_timeout])
-        is_expected.to contain_novajoin_config('keystone_authtoken/memcache_secret_key').with_value(params[:memcache_secret_key])
+        is_expected.to contain_novajoin_config('keystone_authtoken/memcache_secret_key').with_value(params[:memcache_secret_key]).with_secret(true)
         is_expected.to contain_novajoin_config('keystone_authtoken/memcache_security_strategy').with_value(params[:memcache_security_strategy])
         is_expected.to contain_novajoin_config('keystone_authtoken/memcache_use_advanced_pool').with_value(params[:memcache_use_advanced_pool])
         is_expected.to contain_novajoin_config('keystone_authtoken/memcached_servers').with_value('memcached01:11211,memcached02:11211')
