@@ -26,7 +26,7 @@ describe 'nova::placement' do
         is_expected.to contain_nova_config('placement/project_name').with_value(default_params[:project_name])
         is_expected.to contain_nova_config('placement/project_domain_name').with_value(default_params[:project_domain_name])
         is_expected.to contain_nova_config('placement/region_name').with_value(default_params[:region_name])
-        is_expected.to contain_nova_config('placement/os_interface').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('placement/valid_interfaces').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('placement/username').with_value(default_params[:username])
         is_expected.to contain_nova_config('placement/user_domain_name').with_value(default_params[:user_domain_name])
         is_expected.to contain_nova_config('placement/auth_url').with_value(default_params[:auth_url])
@@ -53,7 +53,7 @@ describe 'nova::placement' do
         is_expected.to contain_nova_config('placement/project_name').with_value(params[:project_name])
         is_expected.to contain_nova_config('placement/project_domain_name').with_value(params[:project_domain_name])
         is_expected.to contain_nova_config('placement/region_name').with_value(params[:region_name])
-        is_expected.to contain_nova_config('placement/os_interface').with_value(params[:os_interface])
+        is_expected.to contain_nova_config('placement/valid_interfaces').with_value(params[:os_interface])
         is_expected.to contain_nova_config('placement/username').with_value(params[:username])
         is_expected.to contain_nova_config('placement/user_domain_name').with_value(params[:user_domain_name])
         is_expected.to contain_nova_config('placement/auth_url').with_value(params[:auth_url])
